Module types

Module types 

Built-in data types and their in-memory representations.

Unstable

The APIs exposed by this module are primarily used for code generation and dynamic data manipulation; the exact APIs are subject to change, and may not be well-optimized.

Re-exports

pub use dynamic::Unspecified;

Modules

binary
Binary data types (i.e., bytes).
cryptography
dynamic
Unstable
list
List data types (including [u8] and Option).
map
number
Numeric data types (including bool).

Structs

Coda
In-memory representation of a coda.
DataField
A field in a DataType.
DataType
Data containing a structured set of DataFields.

Enums

Text
UTF-8 encoded text data.
Type
Enumeration of available built in types.

Traits

TryAsFormat
A thing that might contain data with a specific format D.