Trait HasCryptoHash

pub trait HasCryptoHash {
    // Required method
    fn crypto_hash_into(&self, hasher: &mut CryptoHasher);

    // Provided method
    fn crypto_hasher(&self) -> CryptoHasher { ... }
}
A thing that can be represented as a cryptographic hash.

Required Methods

fn crypto_hash_into(&self, hasher: &mut CryptoHasher)

Writes self’s cryptographhically hashable data to hasher.

Provided Methods

fn crypto_hasher(&self) -> CryptoHasher

Returns a new CryptoHasher containing self’s cryptographically hashable data.

The hashable data is not guaranteed to contain the entirety of self’s data. For example, some data structures may contain a certificate that indirectly contains all of self’s data; in these cases, the hashable data returned by this method may be the raw bytes of the certificate’s signature.

Implementors