Struct DynamicDataValue

pub struct DynamicDataValue { /* private fields */ }
Contents of a Dynamic::Data.

Implementations

Source

impl DynamicDataValue

pub fn new(typing: &DataType) -> Self

Returns a new, default data value of typing.

pub fn reset(&mut self)

Removes all values from this data, resetting them to their default values.

pub fn insert(&mut self, name: Text, value: Dynamic)

Inserts a value for the field with name.

pub fn iter(&self) -> impl Iterator<Item = (&DataField, Option<&Dynamic>)>

Returns an iterator over all fields in the data.

The iterator yields fields in order by ordinal, yielding None for unset fields.

pub fn visit_mut(&mut self, proc: impl FnMut(&DataField, &mut Dynamic))

Applies proc to each field in the data.

Fields are visited in order by ordinal. If a field is unset, it will be initialized to a default value before proc is invoked.