Built-in data types and their in-memory representations.
Unstable
The APIs exposed by this module are primarily used for code generation and dynamic data manipulation; the exact APIs are subject to change, and may not be well-optimized.
Re-exports
pub use dynamic::Unspecified;
Modules
- binary
- Binary data types (i.e., bytes).
- cryptography
- dynamic
- Unstable
- list
- List data types (including
[u8]andOption). - map
- number
- Numeric data types (including
bool).
Structs
- Coda
- In-memory representation of a coda.
- Data
Field - A field in a
DataType. - Data
Type - Data containing a structured set of
DataFields.
Enums
Traits
- TryAs
Format - A thing that might contain data with a
specific format
D.